pub(super) fn format_block_summary(
function: &MirFunction,
block_index: usize,
block: &MirBlock,
function_names: &FunctionNames,
) -> StringExpand description
Render a compact block summary for the graph node label.
pub(super) fn format_block_summary(
function: &MirFunction,
block_index: usize,
block: &MirBlock,
function_names: &FunctionNames,
) -> StringRender a compact block summary for the graph node label.