Struct MirCallArgBinding

pub struct MirCallArgBinding<'a> {
    pub arg: &'a MirCallArg,
    pub local: &'a LocalInfo,
}
Shared call-argument query object used by validation and backends.

Fields

arg: &'a MirCallArg

Call argument payload.

local: &'a LocalInfo

Local metadata referenced by the argument.

Implementations

Source

impl<'a> MirCallArgBinding<'a>

pub fn local_id(self) -> MirLocalId

Return the referenced local id.

pub fn is_borrowed(self) -> bool

Return whether the argument mode is read-only borrow.

pub fn is_mutable_borrow(self) -> bool

Return whether the argument mode is mutable borrow.

pub fn is_owned_move(self) -> bool

Return whether the argument mode is owned move.

pub fn is_owned_copy(self) -> bool

Return whether the argument mode is owned copy.

pub fn is_place(self) -> bool

Return whether the argument local stores a place/reference.

pub fn is_mutable_place(self) -> bool

Return whether the argument local stores a mutable place/reference.

pub fn local_ty(self) -> &'a Ty

Return the local semantic type.

pub fn place_item_ty(self) -> Option<&'a Ty>

Return the place item type, when the local is place-shaped.

pub fn requires_deref_read(self) -> bool

Return whether reading the argument as a value requires dereferencing.

pub fn is_slice_place(self) -> bool

Return whether the place item is a slice view.