pub struct MirProgram {
pub functions: PrimaryMap<MirFuncId, MirFunction>,
pub function_names: BTreeMap<String, MirFuncId>,
pub structs: Vec<MirStructDecl>,
pub enums: Vec<MirEnumDecl>,
}Expand description
Whole-program MIR container.
function_names provides fast lookup from source-level function name
to MIR function id.
Fields
functions: PrimaryMap<MirFuncId, MirFunction>Functions stored in the MIR program arena.
function_names: BTreeMap<String, MirFuncId>Lookup table from canonical function name to function id.
structs: Vec<MirStructDecl>Struct declarations referenced by MIR.
enums: Vec<MirEnumDecl>Enum declarations referenced by MIR.
Implementations
Sourceimpl MirProgram
impl MirProgram
Sourcepub fn function_count(&self) -> usize
pub fn function_count(&self) -> usize
Return the number of functions stored in the MIR program.